@@ -12,7 +12,7 @@ use async_std::{
     net::TcpStream,
 };
 #[cfg(feature = "char-device")]
-use char_device::AsyncCharDevice;
+use char_device::AsyncStdCharDevice;
 use duplex::Duplex;
 use std::{
     fmt::{self, Debug},
@@ -31,7 +31,7 @@ use unsafe_io::{
     IntoUnsafeSocket, OwnsRaw,
 };
 #[cfg(all(not(target_os = "wasi"), feature = "socketpair"))]
-use {duplex::HalfDuplex, socketpair::AsyncSocketpairStream};
+use {duplex::HalfDuplex, socketpair::AsyncStdSocketpairStream};
 #[cfg(not(target_os = "wasi"))]
 use {
     os_pipe::{PipeReader, PipeWriter},
@@ -138,30 +138,30 @@ enum DuplexResources {
     #[cfg(not(target_os = "wasi"))] // WASI doesn't support pipes yet
     ChildStdoutStdin((ChildStdout, ChildStdin)),
     #[cfg(feature = "char-device")]
-    CharDevice(AsyncCharDevice),
+    CharDevice(AsyncStdCharDevice),
     TcpStream(TcpStream),
     #[cfg(unix)]
     UnixStream(UnixStream),
     #[cfg(all(not(target_os = "wasi"), feature = "socketpair"))]
-    SocketpairStream(AsyncSocketpairStream),
+    SocketpairStream(AsyncStdSocketpairStream),
     #[cfg(all(not(target_os = "wasi"), feature = "socketpair"))]
     SocketedThreadFunc(
         Option<(
-            AsyncSocketpairStream,
-            JoinHandle<io::Result<AsyncSocketpairStream>>,
+            AsyncStdSocketpairStream,
+            JoinHandle<io::Result<AsyncStdSocketpairStream>>,
         )>,
     ),
     #[cfg(all(not(target_os = "wasi"), feature = "socketpair"))]
     SocketedThread(
         Option<(
-            AsyncSocketpairStream,
+            AsyncStdSocketpairStream,
             JoinHandle<io::Result<Box<dyn HalfDuplex + Send>>>,
         )>,
     ),
     #[cfg(all(not(target_os = "wasi"), feature = "socketpair"))]
     SocketedThreadReadReady(
         Option<(
-            AsyncSocketpairStream,
+            AsyncStdSocketpairStream,
             JoinHandle<io::Result<Box<dyn HalfDuplexReadReady + Send>>>,
         )>,
     ),
@@ -422,7 +422,7 @@ impl AsyncStreamDuplexer {
     #[cfg(feature = "char-device")]
     #[inline]
     #[must_use]
-    pub fn char_device(char_device: AsyncCharDevice) -> Self {
+    pub fn char_device(char_device: AsyncStdCharDevice) -> Self {
         Self::handle(DuplexResources::CharDevice(char_device))
     }
 
@@ -463,7 +463,7 @@ impl AsyncStreamDuplexer {
     /// Duplex with one end of a socketpair stream, taking ownership of it.
     #[cfg(all(not(target_os = "wasi"), feature = "socketpair"))]
     #[must_use]
-    pub fn socketpair_stream(stream: AsyncSocketpairStream) -> Self {
+    pub fn socketpair_stream(stream: AsyncStdSocketpairStream) -> Self {
         Self::handle(DuplexResources::SocketpairStream(stream))
     }
 
@@ -547,7 +547,9 @@ impl AsyncStreamDuplexer {
     /// all pending output.
     #[cfg(all(not(target_os = "wasi"), feature = "socketpair"))]
     pub fn socketed_thread_func(
-        _func: Box<dyn Send + FnOnce(AsyncSocketpairStream) -> io::Result<AsyncSocketpairStream>>,
+        _func: Box<
+            dyn Send + FnOnce(AsyncStdSocketpairStream) -> io::Result<AsyncStdSocketpairStream>,
+        >,
     ) -> io::Result<Self> {
         todo!("async socketed_thread_func")
     }
